@@ -9,8 +9,9 @@ use URI;
 use Moo;
 use Plack::Util;
 use Plack::Test::Simple::Transaction;
+use JSON qw(encode_json);
 
-our $VERSION = '0.000005'; # VERSION
+our $VERSION = '0.000006'; # VERSION
 
 
 sub BUILDARGS {
@@ -52,7 +53,10 @@ sub transaction {
 
     $trans->request->method(uc $meth);
     $trans->request->uri(URI->new($path));
-    $trans->request->content($cont);
+
+    if (defined $cont) {
+        $trans->request->content(ref $cont ? encode_json($cont) : $cont);
+    }
 
     return $trans;
 }
@@ -70,10 +74,9 @@ sub AUTOLOAD {
     my ($self, @args)  = @_;
     my @cmds = split /_/, ($Plack::Test::Simple::AUTOLOAD =~ /.*::([^:]+)/)[0];
 
-    return  @args >= 3 ?
-        # positional arguments
-        $self->transaction($cmds[0], @args)->status_is($cmds[2], $args[2]) :
-        $self->transaction($cmds[0], $args[0])->status_is($cmds[2], $args[1])
+    return $self->transaction($cmds[0], @args[0,1])->status_is(
+            $cmds[2], $args[2]
+        )
         if  @cmds == 3
         && $cmds[0] =~ /^(get|post|put|delete|head|options|connect|patch|trace)$/
         && $cmds[1] eq 'returns'
@@ -100,7 +103,7 @@ Plack::Test::Simple - Object-Oriented PSGI Application Testing
 
 =head1 VERSION
 
-version 0.000005
+version 0.000006
 
 =head1 SYNOPSIS
 
@@ -159,13 +162,13 @@ the HTTP transaction. The actually HTTP request is deferred until the response
 object is needed, this allows you to further modify the transactions HTTP
 request object before it is processed. This method optionally accepts an HTTP
 request method, a request path (or URI object), and content (any string) you
-wish to place in the body of the request.
+wish to place in the body of the request. If the content body argument is a
+Perl object, we will attempt to encode and serialize it automatically using
+JSON. These parameters are used to further modify the transaction's request
+object. Please see the L<Plack::Test::Simple::Transaction> for more information
+on how to use the transaction object to further automate tests.
 
-These parameters are used to further modify the transaction's request object.
-Please see the L<Plack::Test::Simple::Transaction> for more information on how
-to use the transaction object to further automate tests.
-
-    my $tx = $self->transaction('post', '/?query=Perl', $content);
+    my $tx = $self->transaction('post', '/?query=Perl', 'content body');
 
 =head2 connect_returns_CODE
 
@@ -175,7 +178,14 @@ request is made and the server's HTTP response code is tested to ensure it
 returns a CODE. The CODE in this method description is a variable which
 represents any valid HTTP response code, e.g. 200.
 
-    my $tx = $self->connect_returns_200('/path/to/resource', 'test description');
+    my $tx = $self->connect_returns_200(
+        '/path/to/resource', 'content body'
+    );
+
+    # with content body included
+    my $tx = $self->connect_returns_200(
+        '/path/to/resource', 'content body', 'test description'
+    );
 
     # shorthand for
     my $tx = $self->transaction('connect', '/path/to/resource');
@@ -189,7 +199,14 @@ request is made and the server's HTTP response code is tested to ensure it
 returns a CODE. The CODE in this method description is a variable which
 represents any valid HTTP response code, e.g. 200.
 
-    my $tx = $self->delete_returns_200('/path/to/resource', 'test description');
+    my $tx = $self->delete_returns_200(
+        '/path/to/resource', 'content body'
+    );
+
+    # with content body included
+    my $tx = $self->delete_returns_200(
+        '/path/to/resource', 'content body', 'test description'
+    );
 
     # shorthand for
     my $tx = $self->transaction('delete', '/path/to/resource');
@@ -203,7 +220,14 @@ request is made and the server's HTTP response code is tested to ensure it
 returns a CODE. The CODE in this method description is a variable which
 represents any valid HTTP response code, e.g. 200.
 
-    my $tx = $self->get_returns_200('/path/to/resource', 'test description');
+    my $tx = $self->get_returns_200(
+        '/path/to/resource', 'content body'
+    );
+
+    # with content body included
+    my $tx = $self->get_returns_200(
+        '/path/to/resource', 'content body', 'test description'
+    );
 
     # shorthand for
     my $tx = $self->transaction('get', '/path/to/resource');
@@ -217,7 +241,14 @@ request is made and the server's HTTP response code is tested to ensure it
 returns a CODE. The CODE in this method description is a variable which
 represents any valid HTTP response code, e.g. 200.
 
-    my $tx = $self->head_returns_200('/path/to/resource', 'test description');
+    my $tx = $self->head_returns_200(
+        '/path/to/resource', 'content body'
+    );
+
+    # with content body included
+    my $tx = $self->head_returns_200(
+        '/path/to/resource', 'content body', 'test description'
+    );
 
     # shorthand for
     my $tx = $self->transaction('head', '/path/to/resource');
@@ -231,7 +262,14 @@ request is made and the server's HTTP response code is tested to ensure it
 returns a CODE. The CODE in this method description is a variable which
 represents any valid HTTP response code, e.g. 200.
 
-    my $tx = $self->options_returns_200('/path/to/resource', 'test description');
+    my $tx = $self->options_returns_200(
+        '/path/to/resource', 'content body'
+    );
+
+    # with content body included
+    my $tx = $self->options_returns_200(
+        '/path/to/resource', 'content body', 'test description'
+    );
 
     # shorthand for
     my $tx = $self->transaction('options', '/path/to/resource');
@@ -245,7 +283,14 @@ request is made and the server's HTTP response code is tested to ensure it
 returns a CODE. The CODE in this method description is a variable which
 represents any valid HTTP response code, e.g. 200.
 
-    my $tx = $self->patch_returns_200('/path/to/resource', 'test description');
+    my $tx = $self->patch_returns_200(
+        '/path/to/resource', 'content body'
+    );
+
+    # with content body included
+    my $tx = $self->patch_returns_200(
+        '/path/to/resource', 'content body', 'test description'
+    );
 
     # shorthand for
     my $tx = $self->transaction('patch', '/path/to/resource');
@@ -259,7 +304,14 @@ request is made and the server's HTTP response code is tested to ensure it
 returns a CODE. The CODE in this method description is a variable which
 represents any valid HTTP response code, e.g. 200.
 
-    my $tx = $self->post_returns_200('/path/to/resource', 'test description');
+    my $tx = $self->post_returns_200(
+        '/path/to/resource', 'content body'
+    );
+
+    # with content body included
+    my $tx = $self->post_returns_200(
+        '/path/to/resource', 'content body', 'test description'
+    );
 
     # shorthand for
     my $tx = $self->transaction('post', '/path/to/resource');
@@ -273,7 +325,14 @@ request is made and the server's HTTP response code is tested to ensure it
 returns a CODE. The CODE in this method description is a variable which
 represents any valid HTTP response code, e.g. 200.
 
-    my $tx = $self->put_returns_200('/path/to/resource', 'test description');
+    my $tx = $self->put_returns_200(
+        '/path/to/resource', 'content body'
+    );
+
+    # with content body included
+    my $tx = $self->put_returns_200(
+        '/path/to/resource', 'content body', 'test description'
+    );
 
     # shorthand for
     my $tx = $self->transaction('put', '/path/to/resource');
@@ -287,7 +346,14 @@ request is made and the server's HTTP response code is tested to ensure it
 returns a CODE. The CODE in this method description is a variable which
 represents any valid HTTP response code, e.g. 200.
 
-    my $tx = $self->trace_returns_200('/path/to/resource', 'test description');
+    my $tx = $self->trace_returns_200(
+        '/path/to/resource', 'content body'
+    );
+
+    # with content body included
+    my $tx = $self->trace_returns_200(
+        '/path/to/resource', 'content body', 'test description'
+    );
 
     # shorthand for
     my $tx = $self->transaction('trace', '/path/to/resource');
